/* - - - - - - CSS Document - - - - - - - - -

Title : Thickbox styles
Author : Cody Lindley 

- - - - - - - - - - - - - - - - - - - - - */

#TB_overlay {
	position: absolute;
	top: 0;
	left: 0;
	z-index:2000;
	width: 100%;
	height: 100%;
	background-color: #AAA;
	filter:alpha(opacity=50);
	-moz-opacity: 0.5;
	opacity: 0.5;
}

#TB_window {
  display:none;
  color:#000000;
  display:none;
  padding:10px 10px 5px;
  position:absolute;
  left:0;
  top:0;
  z-index:2002;
}

#TB_window #TB_Image {
  border:1px solid white;
  display:block;
}


#TB_caption {
  background-color:black;
  border-bottom:1px solid white;
  border-top:1px solid white;
  color:white;
  display:none;
  float:none;
  font-size:12px;
  font-weight:bold;
  height:14px;
  left:1px;
  line-height:normal;
	filter:alpha(opacity=50);
	-moz-opacity: 0.5;  
  opacity:0.5;
  overflow:hidden;
  padding:3px;
  position:relative;
  text-align:center;
  top:-30px;
}

#TB_caption :hover {
	filter:alpha(opacity=100);
	-moz-opacity: 1;  
  opacity:1;
}


#TB_closeWindow {
  background-color:black;
  border:1px solid white;
  opacity:0.4;
	filter:alpha(opacity=40);
	-moz-opacity: 0.4;  
  padding:2px 5px;
  position:absolute;
  right:20px;
  top:20px;
  text-decoration:none;
  display: block;
}

#TB_closeWindow:hover {
  opacity:1;
	filter:alpha(opacity=100);
	-moz-opacity: 1;    
}

#TB_closeWindowButton {
  border:medium none;
  color:white;
  font-size:12px;
}

#TB_closeAjaxWindow{
	padding:5px 10px 7px 0;
	margin-bottom:1px;
	text-align:right;
	background-color:#e8e8e8;
}

#TB_ajaxContent{
	padding:2px 15px 15px 15px;
	overflow:auto;
	background-color:#FFF;
}

#TB_load{
	text-align: center;
	position: absolute;
	top: 50%;
	left: 0px;
	width: 100%;
	overflow: visible;
	visibility: visible;
	display: block;
	z-index:2001;
}

#TB_loadContent  {
	margin-left: -125px;
	position: absolute;
	top: -50px;
	left: 50%;
	width: 250px;
	/*height: 100px;*/
	visibility: visible;
}
