## -*- coding: utf-8 -*-
## Copyright (C) 2008 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# $Id$

"""
Models params (styles ...)
"""

# images player config #
# MAXWIDTH used for preview images maxwidth & player width
MAXWIDTH = 300
# MAXHEIGHT used for preview images maxheight & player height
MAXHEIGHT = 200
# THUMBMAXWIDTH used for thumbs images maxwidth
THUMBMAXWIDTH = 40
# MAXHEIGHT used for thumbs images maxheight
THUMBMAXHEIGHT = 40
# CONTROLS ORIENTATION ('vertical' or 'horizontal')
CONTROLSORIENTATION = 'horizontal'
# for horizontal controls only ('top' or 'bottom')
HORIZONTALCONTROLSPOSITION = 'bottom'
# for vertical controls only ('left' or 'right')
VERTICALCONTROLSPOSITION = 'right'
# others styles
# SET DISABLESTYLES to True if you prefer to redefine these styles through css
DISABLESTYLES = False
FLOAT = 'right'
BORDERCOLOR = '#DDDCCC'
BGCOLOR = '#F6F6F6'
MARGIN = '0.5em 1em'
