## Script (Python) "pa_innerfile_reference"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=field_name,  uid, widget_index=None
##title=
##

return context.pa_innercontent_reference(field_name, uid, widget_index)